@@ -1,21 +1,25 @@
 import sys
 
-from . import core  # noqa: F401 # imported but unused
-from .core import (  # noqa: F401 # imported but unused
+from . import settings  # noqa: F401 # imported but unused
+from .settings import (  # noqa: F401 # imported but unused
     prefix,
     Settings,
     Setting,
     PropertySetting,
     INVALID_SETTINGS,
-    Behaviors,
-    Behavior,
-    override,
 )
 
+from .exceptions import ValidationError  # noqa: F401 # imported but unused
 from .validators import Validator  # noqa: F401 # imported but unused
 from .types import Undefined  # noqa: F401 # imported but unused
 from .sources import register_source  # noqa: F401 # imported but unused
 from .contrib.behaviors import required  # noqa: F401 # imported but unused
+from .behaviors import (  # noqa: F401 # imported but unused
+    Behavior,
+    GetterSetterBehavior,
+    override,
+    validate,
+)
 
 setting = PropertySetting
 
@@ -34,4 +38,4 @@ def _load_contrib():
 _load_contrib()
 
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
