@@ -1,4 +1,4 @@
-from concrete_settings import Behavior
+from concrete_settings.behaviors import Behavior
 from concrete_settings.validators import RequiredValidator
 
 
@@ -6,6 +6,6 @@ class required(Behavior):
     def __init__(self, message: str = None):
         self.message = message
 
-    def attach_to(self, setting):
+    def decorate(self, setting):
         setting.validators = (RequiredValidator(self.message),) + setting.validators
-        super().attach_to(setting)
+        super().decorate(setting)
